@@ -4,12 +4,12 @@ Photonic::NonRetarded::FieldH
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
-   use Photonic::NonRetarded::Field;
-   my $nrf=Photonic::NonRetarded::Field->new(...);
+   use Photonic::NonRetarded::FieldH;
+   my $nrf=Photonic::NonRetarded::FieldH->new(...);
    my $field=$nrf->evaluate($epsA, $epsB);
 
 =head1 DESCRIPTION
@@ -22,7 +22,7 @@ the components.
 
 =over 4
 
-=item * new(nr=>$nr, nh=>$nh, small=>$small)
+=item * new(nr=>$nr, nh=>$nh, smallE=>$smallE)
 
 Initializes the structure.
 
@@ -32,7 +32,8 @@ structure, *initialized* with the flag keepStates=>1
 
 $nh is the maximum number of Haydock coefficients to use.
 
-$small is the criteria of convergence (default 1e-7)
+$smallE is the criteria of convergence (default 1e-7) for
+Field calculations  
 
 =item * evaluate($epsA, $epsB...)
 
@@ -53,9 +54,9 @@ Photonic::NonRetarded::AllH structure
 
 Maximum number of Haydock coefficients to use.
 
-=item * small
+=item * smallE
 
-Criteria of convergence. 0 means don't check
+Criteria of convergence. 0 means don't check. From Photonic::Roles::EpsParams
 
 =item * epsA
 
@@ -81,6 +82,11 @@ optional reciprocal space filter
 
 real space field in format RorI, cartesian, nx, ny,...
 
+=item * epsL 
+
+Longitudinal dielectric response, obtained colateraly from last
+evaluation of the field
+
 =back
 
 =begin Pod::Coverage
@@ -92,27 +98,30 @@ real space field in format RorI, cartesian, nx, ny,...
 =cut
 
 package Photonic::NonRetarded::FieldH;
-$Photonic::NonRetarded::FieldH::VERSION = '0.007';
+$Photonic::NonRetarded::FieldH::VERSION = '0.008';
+
 use namespace::autoclean;
 use PDL::Lite;
 use PDL::NiceSlice;
 use PDL::Complex;
 use PDL::FFTW3;
 use Photonic::NonRetarded::AllH;
+use Photonic::ExtraUtils qw(cgtsl);
 use Moose;
 use Photonic::Types;
-
+with 'Photonic::Roles::EpsParams';
 
 has 'nr'=>(is=>'ro', isa=>'Photonic::Types::NonRetarded::AllHSave', required=>1,  
            documentation=>'Haydock recursion calculator');
-with 'Photonic::Roles::EpsParams';
 has 'Es'=>(is=>'ro', isa=>'ArrayRef[PDL::Complex]', init_arg=>undef, 
            writer=>'_Es', documentation=>'Field coefficients');
 has 'filter'=>(is=>'ro', isa=>'PDL', predicate=>'has_filter',
                documentation=>'Optional reciprocal space filter');
 has 'field'=>(is=>'ro', isa=>'PDL::Complex', init_arg=>undef,
            writer=>'_field', documentation=>'Calculated real space field');
-
+has 'epsL' =>(is=>'ro', isa=>'PDL::Complex', init_arg=>undef,
+		 writer=>'_epsL', 
+		 documentation=>'Longitudinal dielectric response');
 sub BUILD {
     my $self=shift;
     $self->nr->run unless $self->nr->iteration;
@@ -130,23 +139,23 @@ sub evaluate {
     my $nh=$self->nh; #desired number of Haydock terms
     #don't go beyond available values.
     $nh=$self->nr->iteration if $nh>=$self->nr->iteration;
-    #get field coefficients
-    my $Enp1=0+0*i; #n+1
-    my $En=1+0*i;
-    my @Es; #array of field coefficients
-    unshift @Es, $En; 
-    my $bnp1=0+0*i; #n+1
-    for(my $n=$nh-1; $n>0; --$n){ #downwards iteration
-	my $bn=$bs->[$n];
-	#nm1 means n-1
-	my $Enm1=(($u-$as->[$n])*$En-$bnp1*$Enp1)/$bn; #solve Haydock's row
-	unshift @Es, $Enm1; #save result
-	$Enp1=$En; #shift upwards for next iteration
-	$En=$Enm1;
-	$bnp1=$bn;
-    }
-    my $first=$Es[0];
-    @Es=map {$_/$first} @Es; #Normalize
+    # calculate using linpack for tridiag system
+    # solve \epsilon^LL \vec E^L=D^L.
+    # At first take D=|0>
+    my $diag=$u->complex - PDL->pdl([@$as])->(0:$nh-1);
+    my $subdiag=-PDL->pdl(@$bs)->(0:$nh-1)->r2C;
+    # rotate complex zero from first to last element.
+    my $supradiag=$subdiag->real->mv(0,-1)->rotate(-1)->mv(-1,0)->complex;
+    my $rhs=PDL->zeroes($nh);
+    $rhs->((0)).=1;
+    $rhs=$rhs->r2C;
+    my ($result, $info)= cgtsl($subdiag, $diag, $supradiag, $rhs); 
+    die "Error solving tridiag system" unless $info == 0;
+    # Obtain longitudinal macroscopic response from result
+    $self->_epsL(my $epsL=1/$result->(:,(0)));
+    # Normalize result so macroscopic field is 1.
+    $result*=$epsL;
+    my @Es= map {PDL->pdl($_)->complex} @{$result->unpdl};
     #states are RorI,nx,ny...
     #field is RorY,cartesian,nx,ny...
     my $ndims=$self->nr->B->ndims; # num. of dims of space
@@ -167,6 +176,8 @@ sub evaluate {
     $field_R*=$self->nr->B->nelem; #scale to have unit macroscopic field
     #result is RorI, cartesian, nx, ny,...
     $self->_field($field_R);
+    #my $EM=$field_R->mv(0,-1)->mv(0,-1)->clump(-3)->mv(-2,0)->sumover->mv(-1,1)/$self->nr->B->nelem; 
+    #print "EM=$EM\n";
     return $field_R;
 }
 
