@@ -4,7 +4,7 @@ Photonic::NonRetarded::SH
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -38,23 +38,133 @@ and B materials at the fundamental and the second harmonic frequency
 
 =back
 
-=begin Pod::Coverage
+=head1 ACCESORS (read only)
 
-=head2 BUILD
+=over 4
 
-=end Pod::Coverage
+=item * shp 
+
+Invariant part of SHG calculator.
+
+=item * ndims nrf densityA densityB density nr
+
+Accesors handled by shp
+
+=item * epsA1, epsB1
+
+Dielectric functions of materials A and B at the fundamental frequency
+
+=item * epsA2, epsB2
+
+Dielectric functions of materials A and B at the second harmonic frequency
+
+=item * alpha1
+
+Polarizabity field at the fundamental frequency
+
+=item * alpha2
+
+Polarizabity field at the second harmonic frequency
+
+=item * u1
+
+Spectral variable at fundamental frequency
+
+=item * u2
+
+Spectral variable at second harmonic frequency
+
+=item * field1
+
+longitudinal field at fundamental
+
+=item * field2
+
+longitudinal field at second harmonic
+
+=item * dipolar
+
+Dipolar contribution to SH polarization field
+
+=item * quadrupolar
+
+SH quadrupolar contribution to SH polarization field
+
+=item * external
+
+External contribution to SH polarization field (quadrupolar + dipolar)
+
+=item * external_G
+
+External SH polarization field in reciprocal space
+
+=item * externalL_G
+
+Longitudinal projection of external polarization field in reciprocal space
+
+=item * HP
+
+Photonic::NonRetarded::AllH structure to calculate Haydock basis for
+non linear polarization
+
+=item * externalL_n
+
+External SH polarization field represented in Haydock basis
+
+=item * selfConsistentL_n
+
+SH self consistent longitudinal polarization in Haydock representation
+
+=item * selfConsistentL_G
+
+SH self consistent longitudinal polarization components in reciprocal
+space
+
+=item * selfConsistentVecL_G
+
+SH self consistent longitudinal polarization vector field projection in
+reciprocal space
+
+=item * selfConsistentVecL
+
+SH self consistent longitudinal polarization vector projection field
+in real space
+
+=item * P2
+
+SH self consistent total polarization vector field in real space
+
+=back
+
+=head1 ACCESORS (read/write)
+
+=over 4
+
+=item * filterflag
+
+Flag to filter results in reciprocal space to smooth non linear
+polarization using the field (nrf) filter.
+
+=back
+
+#=begin Pod::Coverage
+#
+#=head2 BUILD
+#
+#=end Pod::Coverage
 
 =cut
 
 package Photonic::NonRetarded::SH;
-$Photonic::NonRetarded::SH::VERSION = '0.007';
+$Photonic::NonRetarded::SH::VERSION = '0.008';
 use namespace::autoclean;
 use PDL::Lite;
 use PDL::NiceSlice;
 use PDL::Complex;
 use PDL::FFTW3;
 use Photonic::NonRetarded::AllH;
-use Photonic::Utils qw(RtoG GtoR HProd cgtsl linearCombine);
+use Photonic::Utils qw(RtoG GtoR HProd linearCombine);
+use Photonic::ExtraUtils qw(cgtsl);
 use Moose;
 use PDL::Constants qw(PI);
 
@@ -81,6 +191,15 @@ has 'u1'=>(is=>'ro', isa=>'PDL::Complex', init_arg=>undef,
 has 'u2'=>(is=>'ro', isa=>'PDL::Complex', init_arg=>undef,
          lazy=>1, builder=>'_build_u2',  
          documentation=>'Spectral variable at SH');
+has 'field1'=>(is=>'ro', isa=>'PDL::Complex', init_arg=>undef,
+         lazy=>1, builder=>'_build_field1', 
+         documentation=>'longitudinal field at fundamental');
+has 'field2'=>(is=>'ro', isa=>'PDL::Complex', init_arg=>undef,
+         lazy=>1, builder=>'_build_field1', 
+         documentation=>'longitudinal field at second harmonic');
+has 'epsL2'=>(is=>'ro', isa=>'PDL::Complex', init_arg=>undef,
+         writer=>'_epsL2', predicate=>'has_epsL2', 
+         documentation=>'longitudinal dielectric function at 2w');
 has 'dipolar'=>(is=>'ro', isa=>'PDL::Complex', init_arg=>undef,
          lazy=>1, builder=>'_build_dipolar', 
          documentation=>'SH dipolar contribution to SH polarization');
@@ -137,16 +256,25 @@ has 'P2'=>(is=>'ro', isa=>'PDL::Complex',
              'SH self consistent total polarization vector
               field in real space');
 
+has 'P2LMCalt'=>(is=>'ro', isa=>'PDL::Complex',
+         init_arg=>undef, lazy=>1,
+         builder=>'_build_P2LMCalt',
+         documentation=>
+             'SH self consistent total macroscopic polarization
+              in real space. Alternative');
+
 has 'filterflag'=>(is=>'rw', 
          documentation=>'Filter results in reciprocal space');
 
-sub BUILD {
-    my $self=shift;
-    $self->nrf->evaluate($self->epsA1, $self->epsB1); #solve linear field
-    #my $nh=$self->nrf->nh;
-    #$nh=$self->nrf->nr->iteration if $nh>=$self->nrf->nr->iteration;
-    #$self->_nh($nh);
-}
+#sub BUILD {
+#    my $self=shift;
+#    #solve linear longitudinal field at w and 2w
+#    $self->_field1($self->nrf->evaluate($self->epsA1, $self->epsB1));
+#    $self->_field2($self->nrf->evaluate($self->epsA2, $self->epsB2));
+#    #my $nh=$self->nrf->nh;
+#    #$nh=$self->nrf->nr->iteration if $nh>=$self->nrf->nr->iteration;
+#    #$self->_nh($nh);
+#}
 
 sub _alpha {
     my $self=shift;
@@ -172,9 +300,20 @@ sub _build_alpha2 {
 }
 
 
+sub _build_field1 {
+    my $self=shift;
+    $self->nrf->evaluate($self->epsA1, $self->epsB1);
+}
+
+sub _build_field2 {
+    my $self=shift;
+    $self->nrf->evaluate($self->epsA2, $self->epsB2);
+    $self->_epsL2($self->nrf->epsL);
+}
+
 sub _build_dipolar {
     my $self=shift;
-    my $field=$self->nrf->field;
+    my $field=$self->field1;
     my $ndims=$self->ndims;
     #E^2 Square each complex component and sum over components
     #result is RorI, nx, ny...
@@ -200,7 +339,7 @@ sub _build_dipolar {
 
 sub _build_quadrupolar {
     my $self=shift;
-    my $field=$self->nrf->field;
+    my $field=$self->field1;
     my $ndims=$self->ndims; #dims of space
     #E E tensor
     #result is RorI, cartesian, cartesian, nx, ny...
@@ -263,8 +402,8 @@ sub _build_HP { #build haydock states for P2
     my $ext=$self->externalL_G;
     my $normext=sqrt(Cabs2($ext)->sum);
     my $extnorm=$ext->complex/$normext;
-    my $hp=Photonic::NonRetarded::AllH->new(	nh=>$self->nrf->nh, 
-	geometry=>$self->nrf->nr->geometry, small=>$self->nrf->nr->small,
+    my $hp=Photonic::NonRetarded::AllH->new(nh=>$self->nrf->nh, 
+	geometry=>$self->nrf->nr->geometry, smallH=>$self->nrf->nr->smallH,
 		keepStates=>1, nextState=>$extnorm);
     $hp->run;
     return $hp;
@@ -290,8 +429,9 @@ sub _build_selfConsistentL_n {
     my $subdiag=-PDL->pdl(@$bs)->(0:$nh-1)->r2C;
     # rotate complex zero from first to last element.
     my $supradiag=$subdiag->mv(0,-1)->rotate(-1)->mv(-1,0);
-    my ($result, $info)=cgtsl($subdiag, $diag, $supradiag, $external);
+    my ($result, $info)= cgtsl($subdiag, $diag, $supradiag, $external); 
     die "Error solving tridiag system" unless $info == 0;
+    $result->complex;
     $result *= $u2/$self->epsA2;
     return $result;
 }    
@@ -332,6 +472,19 @@ sub _build_P2 {
     return $P2;
 }
 
+sub _build_P2LMCalt {
+    my $self=shift;
+    my $Pex=$self->external; #external 2w polarization
+    #normalized longitudinal field.
+    my $field=$self->field2/$self->nrf->nr->geometry->npoints; 
+    #RorI xory nx ny
+    # <0|epsilon^{-1}_{LL}|P^{ex}>
+    my $prod=$field*$Pex; #Notice I don't conjugate. Epsilon is no hermitian
+    $prod=$prod->real->mv(0,-1)->clump(-2)->sumover->complex;
+    die "Strange, no epsilonL2" unless $self->has_epsL2;
+    $prod/=$self->epsL2;
+}
+
 sub _build_u1 {
     my $self=shift;
     #return 1/(1-$self->epsB1/$self->epsA1);
