@@ -4,7 +4,7 @@ Photonic::NonRetarded::SHChiTensor
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -24,7 +24,7 @@ functions of the components.
 
 =over 4
 
-=item * new(geometry=>$g, densityA=>$da, densityB=>$db, nh=>$nh, nhf=>$nhf[, filter=>$ff][, small=>$small])
+=item * new(geometry=>$g, densityA=>$da, densityB=>$db, nh=>$nh, nhf=>$nhf[, filter=>$ff][, smallH=>$smallH][, smallE=>$smallE])
 
 Initializes the structure.
 
@@ -38,13 +38,18 @@ $nhf is the maximum number of Haydock coefficients for the field calculation.
 
 $ff is a (maybe smooth) cutoff function in reciprocal space to smothen the geometry. 
 
-$small is the criteria of convergence (default 1e-7)
+$smallH and $smallE are the criteria of convergence (default 1e-7) for
+haydock coefficients and continued fraction. From Photonic::Roles::EpsParams.
 
-=item * evaluate($epsA1, $epsB1, $epsA2, $epsB2)
+=item * evaluate($epsA1, $epsB1, $epsA2, $epsB2, [$kind])
 
 Returns the macroscopic second Harmonic susceptibility function for a
 given value of the dielectric functions of the host $epsA and the
-=particle $epsB at the fundamental 1 and second harmonic 2 frequency. 
+particle $epsB at the fundamental 1 and second harmonic 2 frequency. 
+$kind is an optional letter for testing purposes with values 'd' for
+dipolar, 'q' for quadrupolar, 'e' for external and 'f' for full
+selfconsistent calculation (the default).
+
 
 =back
 
@@ -52,6 +57,27 @@ given value of the dielectric functions of the host $epsA and the
 
 =over 4
 
+=item * geometry
+
+Photonic::Geometry structure describing the geometry of the
+metamaterial
+
+=item * B dims r G GNorm L scale f
+
+Accesors handled by geometry.
+
+=item * densityA, densityB
+
+Dipole entities density in mediums A and B
+
+=item * nhf 
+
+Maximum number of Haydock coefficients for field calculation
+
+=item * filter
+
+Optional filter to multiply by in reciprocal space 
+
 =item * epsA1, epsB1, epsA2, epsB2
 
 Dielectric functions of components A and B at fundamental and SH frequency
@@ -77,9 +103,10 @@ The actual number of Haydock coefficients used in the last calculation
 
 Flags that the last calculation converged before using up all coefficients
 
-=item * small
+=item * smallH smallE
 
-Criteria of convergence. 0 means don't check.
+Criteria of convergence for Haydock coefficients and for fields. 0
+means don't check. 
 
 =back
 
@@ -96,7 +123,7 @@ Spectral variables
 =cut
 
 package Photonic::NonRetarded::SHChiTensor;
-$Photonic::NonRetarded::SHChiTensor::VERSION = '0.007';
+$Photonic::NonRetarded::SHChiTensor::VERSION = '0.008';
 use namespace::autoclean;
 use PDL::Lite;
 use PDL::NiceSlice;
@@ -106,6 +133,7 @@ use Storable qw(dclone);
 use PDL::IO::Storable;
 use Moose;
 use Photonic::Types;
+with 'Photonic::Roles::EpsParams';
 
 #required parameters
 has 'geometry'=>(is=>'ro', isa => 'Photonic::Geometry',
@@ -115,13 +143,10 @@ has 'densityA'=>(is=>'ro', isa=>'Num', required=>1,
          documentation=>'Normalized dipole entities density in medium A');
 has 'densityB'=>(is=>'ro', isa=>'Num', required=>1,
          documentation=>'Normalized dipole entities density in medium B');
-has 'nh' =>(is=>'ro', isa=>'Num', required=>1, 
-	    documentation=>'Desired no. of Haydock coefficients');
 has 'nhf'=>(is=>'ro', required=>1, 
          documentation=>'Maximum number of desired Haydock
                          coefficients for field calculation');
 #optional parameters 
-has 'small' => (is=>'ro', required=>1, default=>1e-7);
 has 'filter'=>(is=>'ro', isa=>'PDL', predicate=>'has_filter',
                documentation=>'Optional reciprocal space filter');
 
@@ -147,20 +172,31 @@ sub evaluate {
     $self->_epsB1(my $epsB1=shift);
     $self->_epsA2(my $epsA2=shift);
     $self->_epsB2(my $epsB2=shift);
+    my $kind=shift; # Undocumented, for testing: Use full (f) P2 or
+		    # (d) dipolar or (e) external  
     my @P2M; #array of longitudinal polarizations along different directions.
     foreach(@{$self->nrshp}){
 	my $nrsh=Photonic::NonRetarded::SH->new(
 	    shp=>$_, epsA1=>$epsA1, epsB1=>$epsB1, epsA2=>$epsA2,
 	    epsB2=>$epsB2);
 	# RorI, XorY,nx,ny
-	my $P2=$nrsh->P2;
-#	my $P2=$nrsh->dipolar;
-#	my $P2=$nrsh->external;
-	my $P2M=$P2->mv(0,-1)->mv(0,-1)
+	my $P2ex=$nrsh->external;
+	my $P2full=$nrsh->P2;
+	my $P2M=$P2full->mv(0,-1)->mv(0,-1)
 	    ->clump(-3) #linear index, RorI, XorY
 	    ->mv(-2,0) #RorI, index, XorY
 	    ->complex->sumover  #RorI, XorY
 	    /$self->geometry->npoints;
+	#my $field=$nrsh->nrf->evaluate($epsA2->Cconj, $epsB2->Cconj);
+	#Note that epsilonLL is not Hermitian. So I conjugate epsilon
+	#and afterwards  I conjugate the resulting field.
+	#Normalize field
+	#$field/=$self->geometry->npoints;
+	#RorI xory nx ny
+	#my $prod=$field->Cconj*$P2ex;
+	#$prod=$prod->real->mv(0,-1)->mv(0,-1)->clump(-3)->sumover->complex;
+	# I expect $prod to be equal to $P2M, if both were correct(?)
+	#Wrong: I have to make scalar product!
 	push @P2M, $P2M;
     }
     #NOTE. Maybe I have to correct response to D-> response to E
@@ -202,9 +238,9 @@ sub _build_nrshp { # One Haydock coefficients calculator per direction0
 	$g->Direction0($_); #add G0 direction
 	#Build a corresponding NonRetarded::AllH structure
 	my $nr=Photonic::NonRetarded::AllH->new(nh=>$self->nh, geometry=>$g,
-					  keepStates=>1); 
+				keepStates=>1, smallH=>$self->smallH);  
 	my $nrf=Photonic::NonRetarded::FieldH->new(nr=>$nr, nh=>$self->nhf, 
-					small=>$self->small);
+					smallE=>$self->smallE);
 	my $nrshp=Photonic::NonRetarded::SHP->
 	    new(nrf=>$nrf, densityA=>$self->densityA, 
 		densityB=>$self->densityB); 
