@@ -4,7 +4,7 @@ Photonic::NonRetarded::SHP
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -44,7 +44,7 @@ $dB is the density of polarizable entities in medium B
 
 =item * nrf
 
-Haydock field calculator
+Photonic::NonRetarded::FieldH Haydock field calculator
 
 =item * densityA, densityB
 
@@ -52,7 +52,7 @@ Normalized (to what?) dipole entities density in media A and B
 
 =item * density
 
-Density over unit cell
+Density field over unit cell
 
 =item * ndims
 
@@ -69,13 +69,14 @@ Number of dimensions of the system
 =cut
 
 package Photonic::NonRetarded::SHP;
-$Photonic::NonRetarded::SHP::VERSION = '0.007';
+$Photonic::NonRetarded::SHP::VERSION = '0.008';
 use namespace::autoclean;
 use PDL::Lite;
 use PDL::NiceSlice;
 use PDL::Complex;
 use PDL::FFTW3;
-use Photonic::Utils qw(RtoG HProd cgtsl linearCombine);
+use Photonic::Utils qw(RtoG HProd linearCombine);
+use Photonic::ExtraUtils qw(cgtsl);
 use Moose;
 use PDL::Constants qw(PI);
 
