@@ -1,9 +1,9 @@
 package Photonic::Utils;
-$Photonic::Utils::VERSION = '0.007';
+$Photonic::Utils::VERSION = '0.008';
 # Collection of subroutines. Thus, no Moose
 require Exporter;
 @ISA=qw(Exporter);
-@EXPORT_OK=qw(vectors2Dlist tile cmatmult dgtsl cgtsl RtoG GtoR LC
+@EXPORT_OK=qw(vectors2Dlist tile cmatmult  RtoG GtoR LC
               HProd linearCombine);
 use PDL::Lite;
 use PDL::NiceSlice;
@@ -26,20 +26,37 @@ sub linearCombine { #complex linear combination of states
     return $result;
 }
     
-sub HProd { #Hermitean product between two scalar fields
+sub HProd { #Hermitean product between two fields. skip first 'skip' dims
     my $first=shift; 
     my $second=shift;
-    my $iscomplex = 
-	(ref $first eq 'PDL::Complex' and ref $second eq 'PDL::Complex'); 
+    my $skip=shift//0;
+    my $iscomplex = (ref $first eq 'PDL::Complex' or ref $second eq
+	'PDL::Complex');  
     my $ndims=$first->ndims;
+    die "Dimensions should be equal" unless $ndims == $second->ndims;
     my $prod=$first->complex->Cconj*$second->complex;
-    my $result=$prod->mv(0,-1)->clump($ndims-1)->mv(-1,0)->sumover;
+    my $result=$prod->reorder($skip+1..$ndims-1,1..$skip,0)->clump(-1-$skip-1)
+	->mv(-1,0)->sumover;
     #Note: real does not take the real part, just gives a 2-real
     #vector view of each complex
     $result=$result->real unless $iscomplex;
     return $result;
 }
 
+#sub HProd { #Hermitean product between two fields.
+#    my $first=shift; 
+#    my $second=shift;
+#    my $iscomplex = 
+#	(ref $first eq 'PDL::Complex' and ref $second eq 'PDL::Complex'); 
+#    my $ndims=$first->ndims;
+#    my $prod=$first->complex->Cconj*$second->complex;
+#    my $result=$prod->mv(0,-1)->clump($ndims-1)->mv(-1,0)->sumover;
+#    #Note: real does not take the real part, just gives a 2-real
+#    #vector view of each complex
+#    $result=$result->real unless $iscomplex;
+#    return $result;
+#}
+
 
 sub RtoG { #transform a 'complex' scalar, vector or tensorial field
 	   #from real to reciprocal space  
@@ -72,6 +89,7 @@ sub GtoR { #transform a 'complex' scalar, vector or tensorial field from
 sub tile { # repeat field Nx X Ny X... times
     my $f=shift;
     my @n=@_; #number of repetitions along dimension
+    # Is next comment correct (2 X)?
     my $dim=0; #field is 2 X dims X nx,ny,nz...
     my $r=$f; #result
     for my $n(@n){
@@ -93,7 +111,7 @@ sub vectors2Dlist { #2D vector fields ready for gnuploting
     my $d=shift; #decimation
     my $f1=$s*$f->(:,0:-1:$d, 0:-1:$d); #decimate two dimensions
     my $coords=$d*PDL::ndcoords(@{[$f1->dims]}[1,2]);
-    return ( #basx, basey, vectorx vectory
+    return ( #basex, basey, vectorx vectory
 	($coords((0))-.5*$f1((0)))->flat, 
 	($coords((1))-.5*$f1((1)))->flat, 
 	$f1((0))->flat, $f1((1))->flat);
@@ -139,12 +157,11 @@ Photonic::Utils
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
-    use Photonic::Utils qw(cgtsl cmatmult);
-    my ($r, $info)=cgtsl($c,$d,$e, $b);
+    use Photonic::Utils qw(cmatmult);
     $c=cmatmult($a, $b);
 
 =head1 DESCRIPTION
@@ -202,24 +219,6 @@ rows of b, i denotes rows of a and of the result c, k denotes columns
 of b and the result c. Recall that in pdl the first (row) index is
 faster. May thread over extra dimensions.
 
-=item * ($r,$i)=dgtsl($c, $d, $e, $b)
-
-Solves the tridiagonal matrix equation $m x $r=$b. $m is a tridiagonal
-double matrix with subdiagonal $c, diagonal $d and supradiagonal $e, $b is an
-ordinary vector (not necessarily column vector) with the right hand
-side. $r is the result vector and $i is and integer indicator of where the
-calculation failed, zero on success. The signature would be double c(n),
-d(n), e(n), b(n), r(n) and long i(n). May thread over extra dimensions.
-
-=item * ($r,$i)=cgtsl($c, $d, $e, $b)
-
-Solves the tridiagonal matrix equation $m x $r=$b. $m is a tridiagonal
-complex matrix with subdiagonal $c, diagonal $d and supradiagonal $e, $b is an
-ordinary vector (not necessarily column vector) with the right hand
-side. $r is the result vector and $i is and integer indicator of where the
-calculation failed, zero on success. The signature would be double c(2,n),
-d(2,n), e(2,n), b(2,n), r(2,n) and long i(n). May thread over extra dimensions.
-
 =back
 
 =head1 NOTE
@@ -231,16 +230,4 @@ remove the directory _Inline/ before running.
 B<You must make sure that the relative location of the libutils.so
 library is correct.> See $Bin below.
 
-The sources for the Fortran routines cgtsl and dgtsl are in
-F<Photonic/sources>. They must be compiled as
-
-   gfortran -fPIC -c dgtsl.f
-   gfortran -fPIC -c cgtsl.f
-
-and linked to the library as
-
-   gcc -shared -o libutils.so dgtsl.o cgtsl.o
-
-The library is at F<Photonic/lib>.
-
 =cut
